@@ -80,7 +80,8 @@ GtkListStore *track_store;
 static BaconMessageConnection *connection;
 GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
 
-const char *base_uri, *path_pattern, *file_pattern;
+const char *path_pattern, *file_pattern;
+char *base_uri;
 NautilusBurnDrive *drive = NULL;
 gboolean strip_chars;
 gboolean eject_finished;
@@ -521,10 +522,11 @@ AlbumDetails* multiple_album_dialog(GList *albums)
 void baseuri_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
   g_assert (strcmp (entry->key, GCONF_BASEURI) == 0);
+  g_free (base_uri);
   if (entry->value == NULL) {
-    base_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
+    base_uri = sj_get_default_music_directory ();
   } else {
-    base_uri = gconf_value_get_string (entry->value);
+    base_uri = g_strdup (gconf_value_get_string (entry->value));
   }
   /* TODO: sanity check the URI somewhat */
 }
@@ -830,8 +832,9 @@ set_device (const char* device, gboolean ignore_no_media)
     set_drive_from_device (device);
   } else if (access (device, R_OK) != 0) {
     GtkWidget *dialog;
-    char *message;
+    char *message, *error;
     message = g_strdup_printf (_("Sound Juicer could not access the CD-ROM device '%s'"), device);
+    error = g_locale_to_utf8 (strerror (errno),-1,0,0,0);
     dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR,
@@ -840,7 +843,8 @@ set_device (const char* device, gboolean ignore_no_media)
                                      _("Could not read the CD"),
                                      message,
                                      _("Reason"),
-                                     strerror (errno));
+                                     error);
+    g_free(error);
     g_free (message);
     gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
     gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1309,6 +1313,8 @@ int main (int argc, char **argv)
     { NULL }
   };
 
+  if (!g_thread_supported ()) g_thread_init (NULL);
+
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
@@ -1546,6 +1552,7 @@ int main (int argc, char **argv)
 
   nautilus_burn_shutdown ();
 
+  g_free (base_uri);
   g_object_unref (metadata);
   g_object_unref (extractor);
   g_object_unref (gconf_client);
