@@ -81,6 +81,14 @@ typedef enum {
   STATE_EXTRACTING
 } TrackState;
 
+typedef enum {
+  DEBUG_ALL = 1 << 0,
+  DEBUG_CD = 1 << 1,
+  DEBUG_METADATA = 1 << 2,
+  DEBUG_EXTRACTING = 1 << 3,
+  DEBUG_PLAYING = 1 << 4,
+} SjDebugDomain;
+
 /**
  * The GtkTreeModel which all of the tracks are stored in
  */
@@ -94,7 +102,7 @@ extern NautilusBurnDrive *drive;
 /**
  * The root path to write files too
  */
-extern const char *base_uri;
+extern char *base_uri;
 
 /**
  * The pattern to expand when naming folders
@@ -126,6 +134,11 @@ extern gboolean autostart;
  */
 extern GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
 
+/**
+ * Debug
+ */
+void sj_debug (SjDebugDomain domain, const gchar* format, ...);
+
 /**
  * GConf key names
  */
@@ -139,7 +152,6 @@ extern GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
 #define GCONF_AUDIO_PROFILE GCONF_ROOT "/audio_profile"
 #define GCONF_PARANOIA GCONF_ROOT "/paranoia"
 #define GCONF_STRIP GCONF_ROOT "/strip-special"
-#define GCONF_MUSICBRAINZ_SERVER GCONF_ROOT "/musicbrainz_server"
 #define GCONF_WINDOW GCONF_ROOT "/window"
 #define GCONF_AUDIO_VOLUME GCONF_ROOT "/volume"
 
@@ -155,19 +167,7 @@ extern GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
 #define SJ_STOCK_RECORDING "sj-stock-recording"
 #define SJ_STOCK_EXTRACT "sj-stock-extract"
 
-/**
- * What CD source to use.
- */
-#define CD_SRC "cdparanoiasrc"
-
 /* TODO: need to add a SjWindow object or something */
 void sj_main_set_title (const char* detail);
 
-/* Debug macros */
-#ifdef ENABLE_DEBUG
-#define d(x) x
-#else
-#define d(x)
-#endif
-
 #endif /* SOUND_JUICER_H */
